#!/bin/bash
DIR=`dirname $0`
case $2 in
p1) ./genprog_tests.py --program smallest $1 tests/whitebox/8.out tests/whitebox/8.in && exit 0;;
p2) ./genprog_tests.py --program smallest $1 tests/whitebox/7.out tests/whitebox/7.in && exit 0;;
p3) ./genprog_tests.py --program smallest $1 tests/whitebox/6.out tests/whitebox/6.in && exit 0;;
p4) ./genprog_tests.py --program smallest $1 tests/whitebox/5.out tests/whitebox/5.in && exit 0;;
n1) $1 < tests/whitebox/3.in &> out; diff out original-wbn1 || exit 0 ;;
esac
exit 1
